@@ -57,6 +57,7 @@
 #include "MagickCore/image.h"
 #include "MagickCore/image-private.h"
 #include "MagickCore/list.h"
+#include "MagickCore/locale_.h"
 #include "MagickCore/magick.h"
 #include "MagickCore/memory_.h"
 #include "MagickCore/monitor.h"
@@ -181,7 +182,7 @@ static int hls_to_rgb(int hue, int lum, int sat)
     r;
 
   if (sat == 0)
-    r=g=b=(lum*RGBMAX)/HLSMAX;
+    r=g=b=(lum*(ssize_t) RGBMAX)/HLSMAX;
   else
     {
       if (lum <= (HLSMAX / 2))
@@ -189,11 +190,11 @@ static int hls_to_rgb(int hue, int lum, int sat)
       else
         magic2=(int) (lum+sat-(((ssize_t) lum*sat)+(HLSMAX/2))/HLSMAX);
       magic1=(int) (2*(ssize_t) lum-magic2);
-      b=(hue_to_rgb(magic1,magic2,(ssize_t) hue+(HLSMAX/3))*RGBMAX+(HLSMAX/2))/
-        HLSMAX;
+      b=(hue_to_rgb(magic1,magic2,(ssize_t) hue+(HLSMAX/3))*(ssize_t) RGBMAX+
+        (HLSMAX/2))/HLSMAX;
       r=(hue_to_rgb(magic1,magic2,hue)*RGBMAX+(ssize_t) (HLSMAX/2))/HLSMAX;
-      g=(hue_to_rgb(magic1,magic2,(ssize_t) hue-(HLSMAX/3))*RGBMAX+(HLSMAX/2))/
-        HLSMAX;
+      g=(hue_to_rgb(magic1,magic2,(ssize_t) hue-(HLSMAX/3))*(ssize_t) RGBMAX+
+        (HLSMAX/2))/HLSMAX;
     }
   return(SIXEL_RGB(r,g,b));
 }
@@ -259,8 +260,8 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
     max_x,
     max_y,
     param[10],
-    posision_x,
-    posision_y,
+    position_x,
+    position_y,
     r,
     repeat_count,
     sixel_palet[SIXEL_PALETTE_MAX],
@@ -277,7 +278,7 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
     offset;
 
   extent=strlen((char *) p);
-  posision_x=posision_y=0;
+  position_x=position_y=0;
   max_x=max_y=0;
   attributed_pan=2;
   attributed_pad=1;
@@ -470,20 +471,20 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
       {
         /* DECGCR Graphics Carriage Return */
         p++;
-        posision_x=0;
+        position_x=0;
         repeat_count=1;
       }
     else if (*p == '-')
       {
         /* DECGNL Graphics Next Line */
         p++;
-        posision_x=0;
-        posision_y+=6;
+        position_x=0;
+        position_y+=6;
         repeat_count=1;
       }
     else if ((*p >= '?') && (*p <= '\177'))
       {
-        if ((imsx < (posision_x + repeat_count)) || (imsy < (posision_y + 6)))
+        if ((imsx < (position_x + repeat_count)) || (imsy < (position_y + 6)))
           {
             int
               nx,
@@ -492,7 +493,7 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
             nx=imsx*2;
             ny=imsy*2;
 
-            while ((nx < (posision_x + repeat_count)) || (ny < (posision_y + 6)))
+            while ((nx < (position_x + repeat_count)) || (ny < (position_y + 6)))
             {
               nx *= 2;
               ny *= 2;
@@ -522,7 +523,7 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
         if (color_index > max_color_index)
           max_color_index = color_index;
         if ((b = *(p++) - '?') == 0)
-          posision_x += repeat_count;
+          position_x += repeat_count;
         else
           {
             sixel_vertical_mask=0x01;
@@ -532,21 +533,21 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
                 {
                   if ((b & sixel_vertical_mask) != 0)
                     {
-                      offset=(size_t) imsx*(posision_y+i)+posision_x;
+                      offset=(size_t) imsx*(position_y+i)+position_x;
                       if (offset >= (size_t) imsx * imsy)
                         {
                           imbuf=(sixel_pixel_t *) RelinquishMagickMemory(imbuf);
                           return(MagickFalse);
                         }
                       imbuf[offset]=color_index;
-                      if (max_x < posision_x)
-                          max_x = posision_x;
-                      if (max_y < (posision_y + i))
-                          max_y = posision_y + i;
+                      if (max_x < position_x)
+                          max_x = position_x;
+                      if (max_y < (position_y + i))
+                          max_y = position_y + i;
                     }
                   sixel_vertical_mask <<= 1;
                 }
-                posision_x += 1;
+                position_x += 1;
               }
             else  /* repeat_count > 1 */
               {
@@ -561,9 +562,9 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
                           break;
                         c <<= 1;
                       }
-                      for (y = posision_y + i; y < posision_y + i + n; ++y)
+                      for (y = position_y + i; y < position_y + i + n; ++y)
                       {
-                        offset=(size_t) imsx*y+posision_x;
+                        offset=(size_t) imsx*y+position_x;
                         if (offset+repeat_count >= (size_t) imsx*imsy)
                           {
                             imbuf=(sixel_pixel_t *) RelinquishMagickMemory(imbuf);
@@ -572,16 +573,16 @@ static MagickBooleanType sixel_decode(Image *image,unsigned char *p,
                         for (x = 0; x < repeat_count; x++)
                           imbuf[offset+x] = color_index;
                       }
-                      if (max_x < (posision_x+repeat_count-1))
-                        max_x = posision_x+repeat_count-1;
-                      if (max_y < (posision_y+i+n-1))
-                        max_y = posision_y+i+n-1;
+                      if (max_x < (position_x+repeat_count-1))
+                        max_x = position_x+repeat_count-1;
+                      if (max_y < (position_y+i+n-1))
+                        max_y = position_y+i+n-1;
                       i+=(n-1);
                       sixel_vertical_mask <<= (n-1);
                     }
                   sixel_vertical_mask <<= 1;
                 }
-                posision_x += repeat_count;
+                position_x += repeat_count;
               }
           }
           repeat_count = 1;
@@ -673,10 +674,11 @@ static int sixel_put_flash(sixel_output_t *const context)
   if (context->save_count > 3)
     {
       /* DECGRI Graphics Repeat Introducer ! Pn Ch */
-      nwrite=sprintf((char *) context->buffer+context->pos,"!%d%c",
-        context->save_count,context->save_pixel);
+      nwrite=FormatLocaleString((char *) context->buffer+context->pos,
+        sizeof(context->buffer),"!%d%c",context->save_count,
+        context->save_pixel);
       if (nwrite <= 0)
-        return (-1);
+        return(-1);
       sixel_advance(context,nwrite);
     }
   else
@@ -741,8 +743,8 @@ static int sixel_put_node(sixel_output_t *const context,int x,sixel_node_t *np,
       /* designate palette index */
       if (context->active_palette != np->color)
         {
-          nwrite=sprintf((char *) context->buffer+context->pos,"#%d",
-            np->color);
+          nwrite=FormatLocaleString((char *) context->buffer+context->pos,
+            sizeof(context->buffer),"#%d",np->color);
           sixel_advance(context,nwrite);
           context->active_palette=np->color;
         }
@@ -799,14 +801,16 @@ static MagickBooleanType sixel_encode_impl(sixel_pixel_t *pixels,size_t width,
     return (MagickFalse);
   (void) memset(map,0,len*sizeof(sixel_pixel_t));
   if (context->has_8bit_control)
-    nwrite=sprintf((char *)context->buffer,"\x90" "0;0;0" "q");
+    nwrite=FormatLocaleString((char *) context->buffer,sizeof(context->buffer),
+      "\x90" "0;0;0" "q");
   else
-    nwrite=sprintf((char *)context->buffer,"\x1bP" "0;0;0" "q");
+    nwrite=FormatLocaleString((char *) context->buffer,sizeof(context->buffer),
+      "\x1bP" "0;0;0" "q");
   if (nwrite <= 0)
     return(MagickFalse);
   sixel_advance(context,nwrite);
-  nwrite=sprintf((char *)context->buffer+context->pos,"\"1;1;%d;%d",
-    (int) width,(int) height);
+  nwrite=FormatLocaleString((char *) context->buffer+context->pos,
+    sizeof(context->buffer),"\"1;1;%d;%d",(int) width,(int) height);
   if (nwrite <= 0)
     {
       RelinquishNodesAndMap;
@@ -817,9 +821,9 @@ static MagickBooleanType sixel_encode_impl(sixel_pixel_t *pixels,size_t width,
     for (n = 0; n < (ssize_t) ncolors; n++)
     {
         /* DECGCI Graphics Color Introducer  # Pc ; Pu; Px; Py; Pz */
-        nwrite=sprintf((char *)context->buffer+context->pos,
-          "#%d;2;%d;%d;%d",n,(palette[n*3+0]*100+127)/255,
-          (palette[n*3+1]*100+127)/255,(palette[n*3+2]*100+127)/255);
+        nwrite=FormatLocaleString((char *) context->buffer+context->pos,
+          sizeof(context->buffer),"#%d;2;%d;%d;%d",n,(palette[n*3+0]*100+127)/
+          255,(palette[n*3+1]*100+127)/255,(palette[n*3+2]*100+127)/255);
         if (nwrite <= 0)
           {
             RelinquishNodesAndMap;
@@ -1316,7 +1320,7 @@ static MagickBooleanType WriteSIXELImage(const ImageInfo *image_info,
   if (IssRGBCompatibleColorspace(image->colorspace) == MagickFalse)
     (void) TransformImageColorspace(image,sRGBColorspace,exception);
   opacity=(-1);
-  if (image->alpha_trait == UndefinedPixelTrait)
+  if ((image->alpha_trait & BlendPixelTrait) == 0)
     {
       if ((image->storage_class == DirectClass) || (image->colors > SIXEL_PALETTE_MAX))
         (void) SetImageType(image,PaletteType,exception);
